$.jqplot.AxisTickRenderer

A “tick” object showing the value of a tick/gridline on the plot.

Summary

$.jqplot.AxisTickRenderer | A “tick” object showing the value of a tick/gridline on the plot.
Properties |
mark | tick mark on the axis.
showMark | whether or not to show the mark on the axis.
showGridline | whether or not to draw the gridline on the grid at this tick.
isMinorTick | if this is a minor tick.
size | Length of the tick beyond the grid in pixels.
markSize | Length of the tick marks in pixels.
show | whether or not to show the tick (mark and label).
showLabel | whether or not to show the label.
formatter | A class of a formatter for the tick text.
prefix | String to prepend to the tick label.
suffix | String to append to the tick label.
formatString | string passed to the formatter.
fontFamily | css spec for the font-family css attribute.
fontSize | css spec for the font-size css attribute.
textColor | css spec for the color attribute.
escapeHTML | true to escape HTML entities in the label.

### Properties

### mark

> this.mark = 'outside'

tick mark on the axis. One of ‘inside’, ‘outside’, ‘cross’, ‘’ or null.

### showMark

> this.showMark = true

whether or not to show the mark on the axis.

### showGridline

> this.showGridline = true

whether or not to draw the gridline on the grid at this tick.

### isMinorTick

> this.isMinorTick = false

if this is a minor tick.

### size

> this.size = 4

Length of the tick beyond the grid in pixels. DEPRECATED: This has been superceeded by markSize

### markSize

> this.markSize = 6

Length of the tick marks in pixels. For ‘cross’ style, length will be stoked above and below axis, so total length will be twice this.

### show

> this.show = true

whether or not to show the tick (mark and label). Setting this to false requires more testing. It is recommended to set showLabel and showMark to false instead.

### showLabel

> this.showLabel = true

whether or not to show the label.

### formatter

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text. sprintf by default.

### prefix

> this.prefix = ''

String to prepend to the tick label. Prefix is prepended to the formatted tick label.

### suffix

> this.suffix = ''

String to append to the tick label. Suffix is appended to the formatted tick label.

### formatString

> this.formatString = ''

string passed to the formatter.

### fontFamily

> this.fontFamily

css spec for the font-family css attribute.

### fontSize

> this.fontSize

css spec for the font-size css attribute.

### textColor

> this.textColor

css spec for the color attribute.

### escapeHTML

> this.escapeHTML = false

true to escape HTML entities in the label.

> this.mark = 'outside'

tick mark on the axis.

> this.showMark = true

whether or not to show the mark on the axis.

> this.showGridline = true

whether or not to draw the gridline on the grid at this tick.

> this.isMinorTick = false

if this is a minor tick.

> this.size = 4

Length of the tick beyond the grid in pixels.

> this.markSize = 6

Length of the tick marks in pixels.

> this.show = true

whether or not to show the tick (mark and label).

> this.showLabel = true

whether or not to show the label.

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text.

> this.prefix = ''

String to prepend to the tick label.

> this.suffix = ''

String to append to the tick label.

> this.formatString = ''

string passed to the formatter.

> this.fontFamily

css spec for the font-family css attribute.

> this.fontSize

css spec for the font-size css attribute.

> this.textColor

css spec for the color attribute.

> this.escapeHTML = false

true to escape HTML entities in the label.
Close